@@ -10,13 +10,14 @@
 # $2 = version
 # $3 = file
 DIR=mina2-$2.orig
-TAR=mina2_$2+dfsg.orig.tar.gz
+TAR=../mina2_$2+dfsg.orig.tar.gz
 
 # clean up the upstream tarball
 tar zxf $3
 mv apache-mina-* $DIR
 GZIP=--best tar czf $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR
+rm $3
 
 # move to directory 'tarballs'
 if [ -r .svn/deb-layout ]; then
